from pylab import *
from matplotlib.patches import Polygon
import sys

filename = None
if len(sys.argv) >= 2:
    filename = sys.argv[1]
    

figure(facecolor='w', figsize=[4,3])
border = 0.15
ax = axes([border,border,1-2*border,1-2*border])
ax.set_xticks(range(-10,11,1))
ax.set_yticks(range(-10,11,1))
ax.grid()

ax.set_title("Limo paradox, garage frame")
ax.set_xlabel("Distance (light seconds)")
ax.set_ylabel("Time (seconds)")

# add light beams
ax.plot([-10,10],[-10,10], 'b-')
ax.plot([10,-10],[-10,10], 'b-')

# switch to a moving observer
v = 0.661
width = 1
gamma = 1.0/sqrt(1-v**2)
t= arange(-5,10,1)

# plot his spaceship
spaceship = Polygon([(v*t[0]-width,t[0]),   (v*t[0], t[0]),
                     (v*t[-1],t[-1]),       (v*t[-1]-width, t[-1])],
                    alpha=0.2, facecolor='k')
ax.add_patch(spaceship)

# plot the position track of a moving observer
ax.plot(v*t,t, 'r-')

# plot the position track of the garage
ax.plot(0*t,t, 'g-')
ax.plot(-width+0*t,t, 'g-')

# plot his xprime axis at his 1 second intervals
tp = gamma*t
def plot_xp(tp, v, xmin=-10, xmax=10):
    x = arange(xmin, xmax, 0.01)
    xp_y = x*v
    for t in tp:
        origin_x = v*t
        origin_y = t
        ax.plot(x+origin_x, xp_y+origin_y, 'r:')
plot_xp(tp, v)

# plot his tprime grids at his 1 light-second intervals
xp = tp
def plot_tp_grid(xp, v, tmin=-10, tmax=10):
    t = arange(tmin, tmax, 0.01)
    tp_x = t*v
    for x in xp:
        origin_x = x
        origin_y = v*x
        ax.plot(tp_x+origin_x, t+origin_y, 'r:')
plot_tp_grid(xp, v)

proper_width = gamma*width
x_back_limo_frame = -proper_width
t_back_limo_frame = 0
x_back_limo_frame_p = gamma*(x_back_limo_frame+v*t_back_limo_frame)
t_back_limo_frame_p = gamma*(t_back_limo_frame+v*x_back_limo_frame)
x_gar_limo_frame = -width/gamma
t_gar_limo_frame = 0
x_gar_limo_frame_p = gamma*(x_gar_limo_frame+v*t_gar_limo_frame)
t_gar_limo_frame_p = gamma*(t_gar_limo_frame+v*x_gar_limo_frame)
points = [(0,0), (-width,0), (x_back_limo_frame_p, t_back_limo_frame_p),
          (x_gar_limo_frame_p, t_gar_limo_frame_p)]
labels = ["A", "B", "C", "D"]

ax.plot([p[0] for p in points], [p[1] for p in points], 'ko')
for p,L in zip(points, labels):
    ax.text(p[0], p[1], '  '+L,
            horizontalalignment='left',
            verticalalignment='center')

ax.set_ybound(-2,0.5)
ax.set_xbound(-2,0.5)
ax.set_aspect('equal')   # Make aspect ratio equal to 1

if filename == None:
    show()
else:
    savefig(filename, dpi=200)
